TensorPrintHelpers<T extends TypedData> extension

on

Methods

Available on Tensor<T>, provided by the TensorPrintHelpers extension

Returns a string representation of the first counts elements along each dimension. If pretty is true, the output is formatted with newlines and indentation.
tail(List<int> counts, {bool pretty = false}) Future<String>

Available on Tensor<T>, provided by the TensorPrintHelpers extension

Returns a string representation of the last counts elements along each dimension. If pretty is true, the output is formatted with newlines and indentation.