TensorPrintHelpers<T extends TypedData> extension
- on
-
- Tensor<
T>
- Tensor<
Methods
-
head(
List< int> counts, {bool pretty = false}) → Future<String> -
Available on Tensor<
Returns a string representation of the firstT> , provided by the TensorPrintHelpers extensioncountselements along each dimension. Ifprettyis true, the output is formatted with newlines and indentation. -
tail(
List< int> counts, {bool pretty = false}) → Future<String> -
Available on Tensor<
Returns a string representation of the lastT> , provided by the TensorPrintHelpers extensioncountselements along each dimension. Ifprettyis true, the output is formatted with newlines and indentation.